@@ -1,3 +1,4 @@
+import signal
 import subprocess
 import os
 from . import paths
@@ -38,6 +39,12 @@ def hostname():
 def remove(file):
     command(['rm', '-rf', file])
 
+def kill_process(pid):
+    if not isinstance(pid, int):
+        pid = int(pid)
+    os.kill(pid, signal.SIGTERM)
+
+
 
 if __name__ == '__main__':
-    print(ip_address())
\ No newline at end of file
+    pass
