@@ -1,9 +1,9 @@
 import os
 import shutil
 import subprocess
+from utils import exceptions
 
-
-def _command(args: list):
+def __command(args: list):
     sub = subprocess.Popen(args, stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT)
     sub.wait()
     sub.kill()
@@ -117,8 +117,13 @@ def join(path1: str, path2: str):
     path = path1 + path2
     return path
 
-def remove_file(file, blank):
-    _command(['rm', '-rf', file])
+
+def remove(file):
+    # pure python way to remove files
+    if os.path.isdir(file):
+        shutil.rmtree(file)
+    else:
+        os.remove(file)
 
 
 class Path:
@@ -174,6 +179,9 @@ class Path:
     def __abs__(self):
         return self.path
 
+    def __str__(self):
+        return abs(self)
+
     def __len__(self):
         if directory_exists(self.path):
             return len(os.listdir(self.path))
@@ -199,7 +207,10 @@ class Path:
 
 
 
-
+# Depreciated Functions
+def remove_file(file, blank):
+    # _command(['rm', '-rf', file])
+    raise exceptions.DepreciatedFunction(__file__, 'remove_file')
 
 
 if __name__ == '__main__':
